@@ -26,6 +26,7 @@ use chrono::{
     prelude::{DateTime, Utc},
     NaiveDateTime,
 };
+use chrono_tz::Tz;
 use std::{
     fmt::{self, Formatter},
     str,
@@ -63,6 +64,17 @@ impl fmt::Display for StorageHeader {
     }
 }
 
+impl StorageHeader {
+    pub fn as_tz_string(&self, tz: &Tz) -> String {
+        format!(
+            "{}{}{}",
+            self.timestamp.tz_string(tz),
+            DLT_COLUMN_SENTINAL,
+            self.ecu_id
+        )
+    }
+}
+
 impl fmt::Display for ApplicationTraceType {
     fn fmt(&self, f: &mut Formatter) -> Result<(), fmt::Error> {
         match self {
@@ -204,15 +216,64 @@ impl fmt::Display for LogLevel {
     }
 }
 
+#[derive(Default)]
+pub struct FormatOptions {
+    pub tz: Option<Tz>,
+}
+
 /// A dlt message that can be formatted with optional FIBEX data support
 pub struct FormattableMessage<'a> {
     pub message: Message,
     pub fibex_metadata: Option<&'a FibexMetadata>,
+    pub options: Option<&'a FormatOptions>,
+}
+
+impl<'a> From<Message> for FormattableMessage<'a> {
+    fn from(message: Message) -> Self {
+        FormattableMessage {
+            message,
+            fibex_metadata: None,
+            options: None,
+        }
+    }
 }
 
 impl<'a> fmt::Display for FormattableMessage<'a> {
     fn fmt(&self, f: &mut Formatter) -> Result<(), fmt::Error> {
-        self.message.fmt_as_text(f, self.fibex_metadata)
+        self.message
+            .fmt_as_text(f, self.fibex_metadata, self.options)
+    }
+}
+
+impl DltTimeStamp {
+    pub fn tz_string(&self, tz: &Tz) -> String {
+        let naive: Option<NaiveDateTime> =
+            NaiveDateTime::from_timestamp_opt(i64::from(self.seconds), self.microseconds * 1000);
+        match naive {
+            Some(n) => DateTime::<Utc>::from_utc(n, Utc)
+                .with_timezone(tz)
+                .to_string(),
+            None => format!(
+                "no valid timestamp for {}s/{}us",
+                self.seconds, self.microseconds,
+            ),
+        }
+    }
+
+    pub fn utc_string(&self) -> String {
+        let naive: Option<NaiveDateTime> =
+            NaiveDateTime::from_timestamp_opt(i64::from(self.seconds), self.microseconds * 1000);
+        match naive {
+            Some(n) => {
+                let datetime: DateTime<Utc> = DateTime::from_utc(n, Utc);
+                let system_time: std::time::SystemTime = std::time::SystemTime::from(datetime);
+                humantime::format_rfc3339(system_time).to_string()
+            }
+            None => format!(
+                "no valid timestamp for {}s/{}us",
+                self.seconds, self.microseconds,
+            ),
+        }
     }
 }
 
@@ -234,9 +295,14 @@ impl Message {
         &self,
         f: &mut fmt::Formatter,
         fibex_metadata: Option<&FibexMetadata>,
+        options: Option<&FormatOptions>,
     ) -> fmt::Result {
         if let Some(h) = &self.storage_header {
-            write!(f, "{}", h)?;
+            let tz = options.map(|o| o.tz);
+            match tz {
+                Some(Some(tz)) => write!(f, "{}", h.as_tz_string(&tz))?,
+                _ => write!(f, "{}", h)?,
+            };
         }
         write!(f, "{}", DLT_COLUMN_SENTINAL,)?;
         write!(f, "{}", self.header)?;
